CheckoutData class

Constructors

CheckoutData({required String? id, required String? status, required String? language, required String? merchantWebsite, required int? pageExpiration, required String? redirectUrl, required String? country, required String? currency, required double? amount, required Payment payment, required dynamic paymentMethodType, required dynamic paymentMethodTypeCategories, required List<String>? paymentMethodTypesInclude, required dynamic paymentMethodTypesExclude, required dynamic customer, required int? timestamp, required dynamic paymentExpiration, required dynamic escrow, required dynamic escrowReleaseDays})
CheckoutData.fromJson(Map<String, dynamic> json)
factory
CheckoutData.fromRawJson(String str)
factory

Properties

amount → double?
final
country → String?
final
currency → String?
final
customer → dynamic
final
escrow → dynamic
final
escrowReleaseDays → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
language → String?
final
merchantWebsite → String?
final
pageExpiration → int?
final
payment → Payment
final
paymentExpiration → dynamic
final
paymentMethodType → dynamic
final
paymentMethodTypeCategories → dynamic
final
paymentMethodTypesExclude → dynamic
final
paymentMethodTypesInclude → List<String>?
final
redirectUrl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
final
timestamp → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited