CustomerData class

Constructors

CustomerData({required String id, required String name, required String? defaultPaymentMethod, required String? description, required String email, required String? invoicePrefix, required int createdAt, required String? businessVatId, required String? ewallet})
CustomerData.fromJson(Map<String, dynamic> json)
factory
CustomerData.fromRawJson(String str)
factory

Properties

businessVatId → String?
final
createdAt → int
final
defaultPaymentMethod → String?
final
description → String?
final
email → String
final
ewallet → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
invoicePrefix → String?
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited