Address class

Constructors

Address({required String id, required String name, required String line1, required String? line2, required String city, required String state, required String country, required String zip, required dynamic phoneNumber, required int createdAt})
Address.fromJson(Map<String, dynamic> json)
factory
Address.fromRawJson(String str)
factory

Properties

city → String
final
country → String
final
createdAt → int
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
line1 → String
final
line2 → String?
final
name → String
final
phoneNumber → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String
final
zip → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited