PaymentData class

Constructors

PaymentData({required String id, required double amount, required bool isPartial, required String currencyCode, required String countryCode, required String status, required PaymentMethodData paymentMethodData, required PaymentStatusMetadata metadata, required bool paid, required int paidAt})
PaymentData.fromJson(Map<String, dynamic> json)
factory
PaymentData.fromRawJson(String str)
factory

Properties

amount → double
final
countryCode → String
final
currencyCode → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
isPartial → bool
final
metadata → PaymentStatusMetadata
final
final
paidAt → int
final
paymentMethodData → PaymentMethodData
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited