PaymentMethodData class

Constructors

PaymentMethodData({required String id, required String type, required Address address, required String name, required String last4, required String expirationYear, required String expirationMonth, required String fingerprintToken})
PaymentMethodData.fromJson(Map<String, dynamic> json)
factory
PaymentMethodData.fromRawJson(String str)
factory

Properties

address → Address
final
expirationMonth → String
final
expirationYear → String
final
fingerprintToken → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
last4 → String
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited