Status class

Constructors

Status({required String? errorCode, required String status, required String? message, required String? responseCode, required String operationId})
Status.fromJson(Map<String, dynamic> json)
factory
Status.fromRawJson(String str)
factory

Properties

errorCode → String?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
operationId → String
final
responseCode → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toRawJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited